@@ -259,68 +259,4 @@ public class POMReader {
         }
         return str;
     }
-
-    static class TreePath<S> {
-        private LinkedList<S> path = new LinkedList<S>();
-
-        // forwarding functions to the inner LinkedList
-        public void add(S el) { path.addLast(el); }
-        public void remove() { path.removeLast(); }
-        public boolean contains(S el) { return path.contains(el); }
-        public int size() { return path.size(); }
-        public S get(int index) { return path.get(index); }
-
-        public S parent(int generations) {
-            int index = (path.size() - 1) - generations;
-            return index >= 0 ? path.get(index) : null;
-        }
-
-        private boolean matches(String patternString, boolean anchored) {
-            String[] patterns = patternString.split("/");
-
-            if(anchored && patterns.length != path.size()) return false;
-
-            int pathIndex = path.size() - patterns.length - 1;
-            if(pathIndex < -1) return false;
-
-            for (String pattern : patterns) {
-                ++pathIndex;
-                if ("*".equals(pattern)) {
-                    continue;
-                }
-                if (!pattern.equals(path.get(pathIndex))) {
-                    return false;
-                }
-            }
-            return true;
-        }
-
-        /**
-         * Does this path match the pattern?
-         * 
-         * The pattern is separated by slashes / and can contain the * wildcard for any path element to match
-         * anything. The matching is anchored at the end of the path. So the pattern does not need to start at
-         * the root.
-         * 
-         * A pattern that starts with a slash is also anchored at the start.
-         * 
-         * @param patternString
-         */
-        public boolean matches(String patternString) {
-            if(patternString.startsWith("/")) {
-                return matches(patternString.substring(1), true);
-            } else {
-                return matches(patternString, false);
-            }
-        }
-        
-        public DependencyType match() {
-            for(DependencyType depType : DependencyType.values()) {
-                if(matches(depType.pattern)) {
-                    return depType;
-                }
-            }
-            return null;
-        }
-    }
 }
